@@ -89,7 +89,7 @@ class ADQLGeometryTranslationVisitor(ADQLParserVisitor):
             except ValueError:
                 try:
                     val = float(eval(i))
-                except (AttributeError, ValueError, NameError):
+                except (AttributeError, ValueError, NameError, SyntaxError):
                     if self.output_sql == 'mysql':
                         val = '.'.join('`{0}`'.format(v.rstrip("'").
                                                       lstrip("'").
@@ -117,9 +117,16 @@ class ADQLGeometryTranslationVisitor(ADQLParserVisitor):
     def visitAs_clause(self, ctx):
         # We need to visit the AS clause to avoid aliases being treated same
         # as regular identifiers and backticked.
-        ri = _process_regular_identifier(ctx.children[1].getText(),
-                                         self.output_sql)
-        if ctx.children[1].getText()[0] != '"':
+        try:
+            ri = _process_regular_identifier(ctx.children[1].getText(),
+                                             self.output_sql)
+            alidx = 1
+        except IndexError:
+            ri = _process_regular_identifier(ctx.children[0].getText(),
+                                             self.output_sql)
+            alidx = 0
+
+        if ctx.children[alidx].getText()[0] != '"':
             if self.output_sql == 'mysql':
                 ri = ri.replace('`', '')
         _remove_children(ctx)
@@ -152,10 +159,16 @@ class ADQLGeometryTranslationVisitor(ADQLParserVisitor):
         for j in range(0, 5, 2):
             pars.extend(self._convert_values(ctx, s + j))
 
+        try:
+            topright_x = float(pars[0]) + float(pars[2])
+            topright_y = float(pars[1]) + float(pars[3])
+        except ValueError:
+            raise QueryError('sbox values incorrect')
+
         if self.output_sql in ('mysql', 'postgresql'):
             ctx_text = "sbox( spoint(%s(%s),%s(%s)),spoint(%s(%s),%s(%s)) )" %\
                 (self.conunits, pars[0], self.conunits, pars[1],
-                 self.conunits, pars[2], self.conunits, pars[3])
+                 self.conunits, '%.12f' % topright_x, self.conunits, '%.12f' % topright_y)
         else:
             ctx_text = ''
 
