@@ -11,6 +11,7 @@ from __future__ import (absolute_import, print_function)
 __all__ = ["PostgreSQLQueryProcessor"]
 
 import antlr4
+import sys
 
 from .PostgreSQLLexer import PostgreSQLLexer
 from .PostgreSQLParser import PostgreSQLParser
@@ -187,12 +188,12 @@ class PostgreSQLQueryProcessor(object):
             calias = c[1]
 
             # if * is selected we don't care too much
-            if c[0][0] is None and c[0][1] is None and c[0][2] == '*':
-                for slt in select_list_tables:
-                    extra_columns.append([[slt[0][0][0], slt[0][0][1], cname,
-                                           c[0][3]], calias])
-                remove_column_idxs.append(i)
-                continue
+            #  if c[0][0] is None and c[0][1] is None and c[0][2] == '*':
+                #  for slt in select_list_tables:
+                    #  extra_columns.append([[slt[0][0][0], slt[0][0][1], cname,
+                                           #  c[0][3]], calias])
+                #  remove_column_idxs.append(i)
+                #  continue
 
             # this can happen for example in ... WHERE EXISTS ... clauses
             if cname is None and calias is None:
@@ -331,8 +332,10 @@ class PostgreSQLQueryProcessor(object):
         # Antlr objects
         inpt = antlr4.InputStream(self.query)
         lexer = PostgreSQLLexer(inpt)
+        #  lexer.removeErrorListeners()
         stream = antlr4.CommonTokenStream(lexer)
         parser = PostgreSQLParser(stream)
+        lexer._listeners = [self.syntax_error_listener]
         parser._listeners = [self.syntax_error_listener]
 
         # Parse the query
@@ -399,7 +402,8 @@ class PostgreSQLQueryProcessor(object):
                 join_using, column_aliases =\
                 self._extract_instances(column_keyword_function_listener)
 
-            tables.extend([i[0][0] for i in select_list_tables])
+            #tables.extend([i[0][0] for i in select_list_tables])
+            tables.extend([i[0] for i in select_list_tables])
 
             # Then we need to connect the column names s with tables and
             # databases
@@ -469,6 +473,14 @@ class PostgreSQLQueryProcessor(object):
                                          for i in mc])
                 raise QueryError("Unreferenced column(s): '%s'." % unref_cols)
 
+        # If we have indexed_objects, we are also accessing those. We
+        # need to add them into the columns stack:
+        if self._indexed_objects is not None:
+            for k, v in self._indexed_objects.items():
+                for vals in v:
+                    touched_columns.append([[vals[0][0], vals[0][1], vals[2],
+                                             None], None])
+                
         touched_columns = set([tuple(i[0]) for i in touched_columns])
 
         # extract display_columns
@@ -504,15 +516,23 @@ class PostgreSQLQueryProcessor(object):
                                 list(self._strip_column(i[1])))
                                 for i in display_columns]
 
-        self.tables = list(set([tuple([i[0].lstrip('"').rstrip('"')
-                        if i[0] is not None else i[0],
-                        i[1].lstrip('"').rstrip('"')
-                        if i[1] is not None else i[1]]) for i in tables]))
+        self.tables = list(set([tuple([i[0][0].lstrip('"').rstrip('"')
+                        if i[0][0] is not None else i[0][0],
+                        i[0][1].lstrip('"').rstrip('"')
+                        if i[0][1] is not None else i[0][1]]) for i in tables]))
 
         # If there are any pg_sphere objects that are indexed we need
         # to replace the ADQL translated query parts with the indexed column
         # names
         if self._indexed_objects is not None:
+            # we need to correctly alias 'pos' columns
+            for k, v in self._indexed_objects.items():
+                self._indexed_objects[k] = list([list(i) for i in v])
+                for i, vals in enumerate(v):
+                    for t in tables:
+                        if vals[0][0] == t[0][0] and vals[0][1] == t[0][1] and \
+                                t[1] is not None:
+                            self._indexed_objects[k][i][2] = t[1] + '.' + self._indexed_objects[k][i][2]
             pg_sphere_listener = PgSphereListener(columns,
                                                   self._indexed_objects)
             self.walker.walk(pg_sphere_listener, tree)
@@ -528,6 +548,12 @@ class PostgreSQLQueryProcessor(object):
         return self._query
 
     def _strip_query(self, query):
+        if sys.version_info[0] < 3:
+            try:
+                query = unicode(query, 'utf-8')
+            except TypeError:
+                # already unicode so we don't do anything
+                pass
         return query.lstrip('\n').rstrip().rstrip(';') + ';'
 
     def _strip_column(self, col):
